@@ -5,14 +5,14 @@
 #![allow(clippy::map_clone)]
 #![deny(
     missing_docs,
-    missing_debug_implementations,
-    clippy::missing_safety_doc
+    unsafe_op_in_unsafe_fn,
+    clippy::missing_safety_doc,
+    missing_debug_implementations
 )]
 
 //! [![CI][1]][0]
 //! [![Security Audit][2]][0]
 //! [![Coverage][3]][4]
-//! [![LoC][5]][0]
 //! [![Docs.rs][6]][7]
 //! [![Crates.io][8]][9]
 //!
@@ -418,7 +418,6 @@
 //! [2]: https://github.com/Kixiron/lasso/workflows/Security%20Audit/badge.svg
 //! [3]: https://coveralls.io/repos/github/Kixiron/lasso/badge.svg?branch=master
 //! [4]: https://coveralls.io/github/Kixiron/lasso?branch=master
-//! [5]: https://tokei.rs/b1/github/Kixiron/lasso
 //! [6]: https://docs.rs/lasso/badge.svg
 //! [7]: https://docs.rs/lasso
 //! [8]: https://img.shields.io/crates/v/lasso.svg
@@ -429,31 +428,31 @@
 //! [`ahash`]: https://crates.io/crates/ahash
 //! [`raw_entry` api]: https://github.com/rust-lang/rust/issues/56167
 
+extern crate alloc;
+
 #[macro_use]
 mod util;
-
-mod arena;
+mod arenas;
 mod interface;
 mod keys;
 mod reader;
 mod resolver;
-mod single_threaded;
+mod rodeo;
 
 pub use interface::{Interner, IntoReader, IntoReaderAndResolver, IntoResolver, Reader, Resolver};
 pub use keys::{Key, LargeSpur, MicroSpur, MiniSpur, Spur};
 pub use reader::RodeoReader;
 pub use resolver::RodeoResolver;
-pub use single_threaded::Rodeo;
+pub use rodeo::Rodeo;
 pub use util::{Capacity, Iter, LassoError, LassoErrorKind, LassoResult, MemoryLimits, Strings};
 
 compile! {
-    if #[feature = "no-std"] {
-        extern crate alloc;
-    }
-
     if #[all(feature = "multi-threaded", not(feature = "no-std"))] {
-        mod multi_threaded;
-        pub use multi_threaded::ThreadedRodeo;
+        mod threaded_rodeo;
+
+        pub use threaded_rodeo::ThreadedRodeo;
+
+    // If the `multi-threaded` and `no-std` features are both active
     } else if #[all(feature = "multi-threaded", feature = "no-std")] {
         compile_error!("The `multi-threaded` and `no-std` features are not supported together");
     }
