@@ -1,23 +1,18 @@
 use crate::{
-    arena::Arena,
+    arenas::AnyArena,
     hasher::RandomState,
     keys::{Key, Spur},
     resolver::RodeoResolver,
     util::{Iter, Strings},
     Rodeo,
 };
+use alloc::vec::Vec;
 use core::{
     hash::{BuildHasher, Hash, Hasher},
     ops::Index,
 };
 use hashbrown::HashMap;
 
-compile! {
-    if #[feature = "no-std"] {
-        use alloc::vec::Vec;
-    }
-}
-
 /// A read-only view of a [`Rodeo`] or [`ThreadedRodeo`] that allows contention-free access to interned strings,
 /// both key to string resolution and string to key lookups
 ///
@@ -33,7 +28,7 @@ pub struct RodeoReader<K = Spur, S = RandomState> {
     map: HashMap<K, (), ()>,
     hasher: S,
     pub(crate) strings: Vec<&'static str>,
-    arena: Arena,
+    __arena: AnyArena,
 }
 
 impl<K, S> RodeoReader<K, S> {
@@ -48,13 +43,13 @@ impl<K, S> RodeoReader<K, S> {
         map: HashMap<K, (), ()>,
         hasher: S,
         strings: Vec<&'static str>,
-        arena: Arena,
+        arena: AnyArena,
     ) -> Self {
         Self {
             map,
             hasher,
             strings,
-            arena,
+            __arena: arena,
         }
     }
 
@@ -254,7 +249,7 @@ impl<K, S> RodeoReader<K, S> {
     where
         K: Key,
     {
-        self.strings.get_unchecked(key.into_usize())
+        unsafe { self.strings.get_unchecked(key.into_usize()) }
     }
 
     /// Gets the number of interned strings
@@ -332,11 +327,13 @@ impl<K, S> RodeoReader<K, S> {
     #[cfg_attr(feature = "inline-more", inline)]
     #[must_use]
     pub fn into_resolver(self) -> RodeoResolver<K> {
-        let RodeoReader { strings, arena, .. } = self;
+        let RodeoReader {
+            strings, __arena, ..
+        } = self;
 
         // Safety: The current reader no longer contains references to the strings
         // in the vec given to RodeoResolver
-        unsafe { RodeoResolver::new(strings, arena) }
+        unsafe { RodeoResolver::new(strings, __arena) }
     }
 }
 
@@ -391,7 +388,8 @@ impl<K, S> PartialEq<Rodeo<K, S>> for RodeoReader<K, S> {
 
 compile! {
     if #[feature = "serialize"] {
-        use crate::Capacity;
+        use crate::{Capacity, arenas::Arena};
+        use alloc::string::String;
         use core::num::NonZeroUsize;
         use hashbrown::hash_map::RawEntryMut;
         use serde::{
@@ -488,7 +486,7 @@ impl<'de, K: Key, S: BuildHasher + Default> Deserialize<'de> for RodeoReader<K,
             map,
             hasher,
             strings,
-            arena,
+            __arena: AnyArena::Arena(arena),
         })
     }
 }
