@@ -1,17 +1,12 @@
 use crate::{
-    arena::Arena,
+    arenas::AnyArena,
     keys::{Key, Spur},
     util::{Iter, Strings},
     Rodeo, RodeoReader,
 };
+use alloc::vec::Vec;
 use core::{marker::PhantomData, ops::Index};
 
-compile! {
-    if #[feature = "no-std"] {
-        use alloc::vec::Vec;
-    }
-}
-
 /// A read-only view of a [`Rodeo`] or [`ThreadedRodeo`] that allows contention-free access to interned strings
 /// with only key to string resolution
 ///
@@ -27,7 +22,7 @@ pub struct RodeoResolver<K = Spur> {
     ///
     /// This is not touched, but *must* be kept since every string in `self.strings`
     /// points to it
-    __arena: Arena,
+    __arena: AnyArena,
     /// The type of the key
     __key: PhantomData<K>,
 }
@@ -40,7 +35,7 @@ impl<K> RodeoResolver<K> {
     /// The references inside of `strings` must be absolutely unique, meaning
     /// that no other references to those strings exist
     ///
-    pub(crate) unsafe fn new(strings: Vec<&'static str>, arena: Arena) -> Self {
+    pub(crate) unsafe fn new(strings: Vec<&'static str>, arena: AnyArena) -> Self {
         Self {
             strings,
             __arena: arena,
@@ -147,7 +142,7 @@ impl<K> RodeoResolver<K> {
     where
         K: Key,
     {
-        self.strings.get_unchecked(key.into_usize())
+        unsafe { self.strings.get_unchecked(key.into_usize()) }
     }
 
     /// Returns `true` if the given key exists in the current interner
@@ -274,7 +269,8 @@ impl<K, S> PartialEq<Rodeo<K, S>> for RodeoResolver<K> {
 
 compile! {
     if #[feature = "serialize"] {
-        use crate::Capacity;
+        use crate::{Capacity, arenas::Arena};
+        use alloc::string::String;
         use core::num::NonZeroUsize;
         use serde::{
             de::{Deserialize, Deserializer},
@@ -327,7 +323,7 @@ impl<'de, K: Key> Deserialize<'de> for RodeoResolver<K> {
 
         Ok(Self {
             strings,
-            __arena: arena,
+            __arena: AnyArena::Arena(arena),
             __key: PhantomData,
         })
     }
